'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ready = ready;
/**
 * Ready wrapper by passing a `callback` function.
 * `options` object is optional, can be passed at action basis.
 * ready action will be dispatched with provided `options` before invoking the `callback` function.
 * This allows us to add reducer for managing state at ready action level with provided `options`.
 *
 * @param  {Function} callback
 * @param  {Object}   [options={}]
 * @return {Object}
 */
function ready(callback) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var type = 'READY_ACTION';
  var readyActionCreator = function readyActionCreator() {
    return { type: type, options: options };
  };

  return function (_ref) {
    var dispatch = _ref.dispatch,
        getState = _ref.getState;

    var p = new Promise(function (resolve, reject) {
      if (typeof callback !== 'function') {
        reject('Invalid callback function!');
      } else {
        resolve(dispatch(readyActionCreator()));
      }
    });

    return p.then(function () {
      return callback(dispatch, getState);
    });
  };
}

/**
 * ready action wrapper middleware.
 * Need to be imported as part of application's middlewares for usage.
 *
 * @return {Function|Object}
 */

exports.default = function () {
  return function (store) {
    return function (next) {
      return function (action) {
        if (typeof action === 'function') {
          return action(store);
        }

        return next(action);
      };
    };
  };
};